# django-pgsoundex

This library allows usage of the PostgreSQL fuzzystrmatch functions. This 
package depends on PostgreSQL, therefore you'll need to have a PostgreSQL 
database setup in settings.

In order to use the package:

pip install django-pgfuzzy

Then add `pgfuzzy` to `INSTALLED_APPS`.

